#######################################################################
# Likelihood function
#


Nllh = function(dat, lrf, pre, dist=10) {

  ##############################################################
  #
  # Internal use only.  Not currently utilized.
  #
  # Negative log likelihood, implemented in S:

  # Compute Y-hat, SSE, and Negative Log LikeliHood from
  #    dat  :    dat object with slots y, x, z of length len
  #    lrf  :    Levy random field w/slots x y z of length n
  #    pre  :    Precision (inverse of variance) for observations
  #    dist :    distance scale, in km
  # Note: Does not reflect regression on covariates ("beta")
  if(missing(dat)) stop("Llh: Need Data object dat.");
  if(missing(lrf)) stop("Llh: Need Levy random field lrf.");
  if(missing(pre)) stop("Llh: Need Precision pre.");
  if(length(dat)==0) return(list(nllh=0, SSE=0, pred=0));  # Okay, sample from prior
  if(lrf@bdy@Geo) {                         # Geodetic (lat/lon) coords?
    R   = 6378.137;                         # Earth's radius in km.
    myf = function (x, y) { cos((x-y)*pi/180); };
  # See lrf-Main for higher-precision version of Geo distance formula...
    costh =
      cos(dat@y*pi/180) %o% cos(lrf@y*pi/180) *
      outer(dat@x, lrf@x, myf) +
      sin(dat@y*pi/180) %o% sin(lrf@y*pi/180);
    d2 = (R*acos(costh))^2;                 # Squared dist in km^2
  } else {                                  # Easy for Cartesian coords:
    d2 = (outer(dat@x, lrf@x, "-"))^2 + (outer(dat@y, lrf@y, "-"))^2;
  }
  YHat = c(exp(-0.5*d2/dist^2) %*% lrf@z);  # Model prediction at wells
# SSE  = c(crossprod(YHat-dat@z));        # Sum of squared residuals
  SSE  = c(crossprod(log(YHat/dat@z)));   # Sum sq resids, log scale
  nllh = (SSE*pre - length(dat)*log(pre))/2;# Negative log likelihood
  return(list(nllh=nllh, SSE=SSE, pred=YHat));
  }



  Nllh.c = function(dat, lrf, pre, dist=10) {

  ##############################################################
  #
  # Internal use only.  Not currently utilized.
  #
  # Negative log likelihood, implemented in c (8-10 times faster):
  #
  # Use compiled c subroutine to:
  # Compute Y-hat, SSE, and Negative Log LikeliHood from
  #    dat  :    dat object with slots y, x, z of length len
  #    lrf  :    Levy random field w/slots x y z of length n
  #    pre  :    Precision (inverse of variance) for observations
  #    dist :    distance scale, in km
  # Note: Does not reflect regression on covariates ("beta")
  if(missing(dat)) stop("Llh: Need Data object dat.");
  if(missing(lrf)) stop("Llh: Need Levy random field lrf.");
  if(missing(pre)) stop("Llh: Need Precision pre.");
  # handle the case with no data
  if(length(dat$z)==0) return( list(nllh=0, SSE = 0) );             
  YHat <- rep(0, length(dat$z));
  SSE  <- 0.0;
  nllh <- 0.0;
  o <- .C("Nllhc",
     datY = as.double(dat$y),       datX = as.double(dat$x),
     datZ = as.double(dat$z),       datLen = as.integer(length(dat$z)),
     datGeo = as.integer(lrf@bdy@Geo),  lrfX   = as.double(lrf@x),
     lrfY   = as.double(lrf@y),         lrfZ   = as.double(lrf@z),
     lrfLen = as.integer(lrf@len),      pre    = as.double(pre),
     dist   = as.double(dist),          nllh   = as.double(nllh),
     SSE    = as.double(SSE),           YHat   = as.double(YHat),
     COPY=c(rep(FALSE,11),rep(TRUE,3)));    # Avoid time+space waste
  return(list(nllh=o$nllh, SSE=o$SSE, pred=o$YHat));
  }
