

harkRegress <- function(response,    # response vector
                        rootFile,    # the root name for the files
                                     # containing the posterior samples.
                        outFile,     # The output file for the regression samples.
                        initPredsInd = rep(1, 31),
                                     # initPredsInd is the initial value of the
                                     # vector of indicators of
                                     # whether to use each predictor (incl. the
                                     # intercept)
                        priorVar = rep(1, 31),
                                     # A vector of prior variance factors for the
                                     # regression coefficients.  
                        nIter = 10,  # The number of iterations of the Markov chain
                                     # to run for every posterior sample from the first stage.
                        priorType = 0,
                                     # priorType: 0= use the unit
				     # information prior of DiMatteo
				     # et al (2001; Biometrika).  This is the only option
                                     # currently.
                        priorInMcmc, # An indicator of whether to use the model
                                     # prior probabilities in the Markov chain.
                                     # This can be used to improve mixing.
                        predPenalty) # The fake prior odds for each
                                     # predictor indicator; the MCMC
                                     # is simulated with these prior odds
                                     # and they are removed for analysis
                                     # of the results.  Can be used to 
                                     # improve mixing.
{
  DatLG = paste(rootFile,"1Out.LG",sep="");     # Log file for first signal
  if(!file.exists(DatLG))
    stop(paste("Unable to read lrf log file",DatLG));
  if( length( initPredsInd ) != 31 )
    stop("initPredsInd must be a vector of zeros and ones, of length 31.")
  if( ( length( priorVar ) != 31 ) || ( any( priorVar ) < 0 ) )
    stop("priorVar must be a vector of nonnegative values, of length 31.")
  
  MyId <- dget(DatLG);                          # Misc stuff from log
  temps <- MyId$temps;
  nTemps <- length(temps);
  predPenalty = rep(predPenalty, each = 5)
  
 .C( "regressSample",
     response = as.double( response ),
     nData = as.integer( length(response) ),
     rootFile = rootFile,
     outFile = outFile,
     nTemps = as.integer( nTemps ),
     initPredsInd = as.double( initPredsInd ),
     priorVar = as.double( priorVar ),
     nIter = as.integer(nIter),
     priorType = as.integer( priorType ),
     priorInMcmc = as.integer( priorInMcmc ),
     predPenalty = as.double( predPenalty ),
     copy = rep(F, 11))

 return(invisible());
}
