// Compiled C subroutine to calculate the average kernel variance from
// the MCMC

#include "LevyInfer.h"
#include <S.h>


extern "C"{

void avgSig2(
  char **DatFL, char **DatVL,               // The filenames for the MCMC output
  double *temps, long *nTemps,     // The temperatures for the parallel tempering process
  long *tempInd,                  // An indicator of which temperature
  double *avgSig2 )          // The calculated avg sig2 values will be
			     // written to avgSig2
{

  int i, nTemps_ = (int) (*nTemps);
  TNT::Array1D<double> tempArr ( nTemps_ );
  for( i=0; i<nTemps_; i++ )
    tempArr[i] = temps[i];

  LevyInfer li( (*DatFL), (*DatVL), tempArr ); 

  Array1D<double> avgSig2Arr = li.avgSig2( (int)(*tempInd) );

  int nSamps = avgSig2Arr.dim();
  for( int i=0; i<nSamps; i++ )
    avgSig2[i] = avgSig2Arr[i];

  return;
}

}
          


