// Compiled C subroutine to obtain a single sample of the Levy random
// field from the MCMC

#include "LevyInfer.h"
#include <S.h>


extern "C"{

void getLrfSamp(
  char **DatFL, char **DatVL,               // The filenames for the MCMC output
  long *sampNum,
  double *temps, long *nTemps,     // The temperatures for the parallel tempering process
  long *tempInd,                  // An indicator of which temperature
  double *xlocs, double *sig2,
  double *heights, long *nAtoms )          // The LRF will be returned in xlocs
                                           // and heights
{

  int i, nTemps_ = (int) (*nTemps);
  TNT::Array1D<double> tempArr ( nTemps_ );
  for( i=0; i<nTemps_; i++ )
    tempArr[i] = temps[i];

  LevyInfer li( (*DatFL), (*DatVL), tempArr ); 

  int natoms = (int) (*nAtoms);
  Array1D<double> xlocsArr(natoms),
    sig2Arr(natoms),
    heightsArr(natoms);
  li.getLrfSamp((int) (*sampNum), xlocsArr, sig2Arr, heightsArr, (int)(*tempInd));

  for( int i=0; i<natoms; i++ ){
    xlocs[i] = xlocsArr[i];
    sig2[i] = sig2Arr[i];
    heights[i] = heightsArr[i];
  }

  return;
}

}
          


