
#include "randGen.h"

#include "jama_cholesky.h"
#include "tnt_array1d_utils.h"
#include "tnt_array2d_utils.h"
#include "moreArray1dUtils.h"
#include "moreArray2dUtils.h"


using TNT::Array1D;
using TNT::Array2D;
using std::cout;
using std::cerr;
using std::endl;

extern "C"
{
  double S_STDCALL S_runif( void );
}

int rdiscrete 
(const TNT::Array1D<double> &prob){

  double unifRV = S_runif();
  int nValues = prob.dim();
  double cumProb=0.0;
  for (int i=0; i<nValues; i++){
    cumProb = cumProb + prob[i];
    if (unifRV < cumProb)  return(i);
  }
  // If the prob vector sums to 1, a value
  // has been returned already.  If not,
  // return a default value.
  return(-1);
}

// Generate from the multivariate normal distribution.  
Array1D<double> rmvnorm
( const Array1D<double> &mean, const Array2D<double> &Sigma){

  int len = mean.dim();

  //Get cholesky decomposition of the matrix Sigma
  JAMA::Cholesky<double> SChol(Sigma);
  Array2D<double> SCholMat;
  if (SChol.is_spd())
    SCholMat = SChol.getL();
  else
    cerr << "Cholesky decomposition failed." << endl;

  // Generate mean.dim() standard normals
  Array1D<double> normRVs (len);
  for (int i=0; i<len; i++)
    normRVs[i] = S_rnorm();
  normRVs = TNT::matmult(SCholMat, normRVs);
  normRVs = mean + normRVs;
  
  return(normRVs);
}
