// Compiled C subroutine to obtain a single kernel variance (where the
// kernel is chosen at random) from each iteration of the MCMC

#include "LevyInfer.h"
#include <S.h>


extern "C"{

void randSig2(
  char **DatFL, char **DatVL,               // The filenames for the MCMC output
  double *temps, long *nTemps,     // The temperatures for the parallel tempering process
  long *tempInd,                  // An indicator of which temperature
  double *randSig2 )          // The random sig2 values will be
			     // written to randSig2
{

  int i, nTemps_ = (int) (*nTemps);
  TNT::Array1D<double> tempArr ( nTemps_ );
  for( i=0; i<nTemps_; i++ )
    tempArr[i] = temps[i];

  LevyInfer li( (*DatFL), (*DatVL), tempArr ); 

  Array1D<double> randSig2Arr = li.randSig2( (int)(*tempInd) );

  int nSamps = randSig2Arr.dim();
  for( int i=0; i<nSamps; i++ )
    randSig2[i] = randSig2Arr[i];

  return;
}

}
          


