// Compiled C subroutine to calculate the atom variance sums for each sample 
// from the MCMC

#include "LevyInfer.h"
#include <S.h>


extern "C"{

void varSums(
  char **DatFL, char **DatVL,               // The filenames for the MCMC output
  double *temps, long *nTemps,     // The temperatures for the parallel tempering process
  long *tempInd,                  // An indicator of which temperature
  double *varSum )          // The calculated var. sum values will be written to varSum
{

  int i, nTemps_ = (int) (*nTemps);
  TNT::Array1D<double> tempArr ( nTemps_ );
  for( i=0; i<nTemps_; i++ )
    tempArr[i] = temps[i];

  LevyInfer li( (*DatFL), (*DatVL), tempArr ); 

  Array1D<double> varSumArr = li.varSums( (int)(*tempInd) );

  int nSamps = varSumArr.dim();
  for( int i=0; i<nSamps; i++ )
    varSum[i] = varSumArr[i];

  return;
}

}
          


