// Compiled C subroutine to calculate the jump height sums for each sample 
// from the MCMC

#include "LevyInfer.h"
#include <S.h>


extern "C"{

void zsums(
  char **DatFL, char **DatVL,               // The filenames for the MCMC output
  double *temps, long *nTemps,     // The temperatures for the parallel tempering process
  long *tempInd,                  // An indicator of which temperature
  double *zsum )                   // The calculated z sum values will be written to zsum.
{

  int i, nTemps_ = (int) (*nTemps);
  TNT::Array1D<double> tempArr ( nTemps_ );
  for( i=0; i<nTemps_; i++ )
    tempArr[i] = temps[i];

  LevyInfer li( (*DatFL), (*DatVL), tempArr ); 

  Array1D<double> zArr = li.zsums( (int)(*tempInd) );

  int nSamps = zArr.dim();
  for( int i=0; i<nSamps; i++ )
    zsum[i] = zArr[i];

  return;
}

}
          


