
###  Get the prior constants for HARK from the simulated data.

remove(list=ls())

# read in the data from file
datSubset = as.matrix( read.table(file = "simulDat.txt", sep = "," ) )
m = ncol(datSubset)
nPats = dim(datSubset)[1]

# specify the epsilon parameter
eps = diff( quantile( as.vector(datSubset), c(0.05, 0.95), na.rm=T ) ) / 5
k = m-1

############################ Now find the prior constants for HARK.

library(mgcv)

source("priorConsts.R")

# remove individuals with a lot of missing data when finding
# the best smoothing parameter
mySp = c()
for( i in (1:nPats) ){
  mySp = c( mySp, empirRep(datSubset, i, k=k, eps=eps, plot=F)$sp )
}

bestSp = median( mySp )
#empirRep(datSubset, 1, k=k, sp = bestSp, eps=eps, plot=T)


pM = priorConstsEM( datSubset, k=k, sp = bestSp/2, eps=eps )
# the prior specification of pM is TOO good, in that the probability that the
# number of mixture components is equal to 2 is typically 1.0.  add a small
# amount of probability for 1 or 3 mixture components, just so that the
# Markov chain can explore the space.
pM[2] = pM[2] + .01
pM[4] = pM[4] + .01
pM = pM / sum(pM)

res = priorConstsTau2(datSubset, varInflate = 1, k=k, sp = bestSp/2)
apre <- res$alpha
rpre <- res$beta

res = priorConstsGamma( datSubset, k=k, eps=eps, sp = bestSp /2)
agam = res$agam
rgam = res$rgam

res = priorConstsSigma2( datSubset, timeInflation = 1, k=k,
  sp = bestSp/2, eps=eps )
asigma = res$asigma
rsigma = res$rsigma

write.table( c(apre, rpre, agam, rgam, asigma, rsigma), file = "hyperParams.txt",
            row.names = F, col.names = F)
write.table( pM, file = "pM.txt", row.names = F, col.names = F)

